一个叫欧维的男人决定去死 (豆瓣)
Description: 一个叫欧维的男人决定去死电影简介和剧情介绍,一个叫欧维的男人决定去死影评、图片、预告片、影讯、论坛、在线购票
Keywords: 一个叫欧维的男人决定去死,En man som heter Ove,一个叫欧维的男人决定去死影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.134豆瓣电影Top250

# 一个叫欧维的男人决定去死 En man som heter Ove (2015)

导演: 汉内斯·赫尔姆
编剧: 汉内斯·赫尔姆 / 弗雷德里克·巴克曼
主演: 罗夫·拉斯加德 / 巴哈·帕斯 / 托比亚斯·阿姆博瑞 / 菲利普·伯格 / 安娜-莱娜·布伦丁 / 博瑞·伦贝里 / 埃达·英格薇 / 弗雷德里克·埃弗斯 / 玛德琳·雅各布松 / 查特里娜·拉松 / 杰克尔·法尔斯特伦
类型: 剧情
官方网站: https://www.nordiskfilm.com/en-man-som-heter-ove-kammar-hem-flera-guldbaggenomineringar
制片国家/地区: 瑞典
语言: 瑞典语 / 波斯语
上映日期: 2015-12-25(瑞典)
片长: 116分钟
又名: 明天别再来敲门(台) / 想死冇咁易(港) / 叫欧裴的男人 / 欧维决定去死 / A Man Called Ove / Mr. Ove
IMDb: tt4080728
豆瓣评分
引用
8.9
440656人评价
5星
54.1%
4星
37.8%
3星
7.5%
2星
0.5%
1星
0.1%
好于 98% 剧情片
想看 看过
评价:
推荐

## 一个叫欧维的男人决定去死的剧情简介 · · · · · ·

欧维（罗夫·拉斯加德 Rolf Lassgård 饰）是一个刻板而又固执的老头，他的妻子半年前死于疾病，留他一人生活在这个混乱不堪的世界之中。每天早晨，欧维都会定时在社区里进行巡视，确认所有的车辆都停在应停的位置，呵斥违反规定私自驶入社区的车辆，赶走四处乱转破坏环境的猫狗，在社区居民眼里，欧维是“来自地狱的恶邻”，可每个人都明白，这其实是欧维对于社区爱之深刻的表现。
某一日，欧维遭到了上司的解雇，离开了恪守了几十年的工作岗位，心灰意冷对现世了无牵挂的欧维决定自杀。然而，就在这个节骨眼上，一位名为帕维娜（巴哈·帕斯 Bahar Pars 饰）的女子和丈夫带着两个孩子搬到了欧维的隔壁，成为了欧维自杀计划的绊脚石。 ©豆瓣

## 一个叫欧维的男人决定去死的演职员 · · · · · · ( 全部 16 )

- 汉内斯·赫尔姆 导演
- 罗夫·拉斯加德 饰 Ove
- 巴哈·帕斯 饰 Parvaneh
- 托比亚斯·阿姆博瑞 饰 Patrick
- 菲利普·伯格 饰 青年欧维
- 安娜-莱娜·布伦丁 饰 Journalisten Lena

## 一个叫欧维的男人决定去死的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片702 · 添加 )

## 一个叫欧维的男人决定去死的获奖情况 · · · · · · ( 全部 )

- 第89届奥斯卡金像奖
- 最佳外语片(提名)
- 汉内斯·赫尔姆

- 第29届欧洲电影奖
- 最佳喜剧片

- 第21届金卫星奖
- 电影部门 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  爱在黎明破晓前

  罗马假日

  婚姻故事

  重庆森林

  恋恋笔记本

  爱乐之城

  泰坦尼克号

  时空恋旅人

  傲慢与偏见

  天使爱美丽

我要写短评

## 一个叫欧维的男人决定去死的短评 · · · · · · ( 全部 122087 条 )

热门 / 最新 / 好友

### 3312 有用 III🌙 看过 2016-07-14 00:53:43

剧情其实特别套路，每一个步骤都似曾相识。欧维就像飞屋环游记中的卡尔，怀念着完美的故人的同时偏执和固执被邻居一点一点的磨平最终变亲近。淡淡的音乐伴随着平凡又不平凡的小人物的一生。最后一幕真的无法不想到泰坦尼克吧。

### 3881 有用 王大根 看过 2016-08-11 23:26:48

巨人的花园，男主年轻时那副严谨又害羞的样子真是太迷人了。

### 3071 有用 我对你的无语简直能沉默整个宇宙 看过 2016-08-27 09:46:43

这部电影的前十分钟就是我们的未来，旁友们。独居，失业，没有另一半，被年轻人嫌弃，想死死不成。

### 2941 有用 BLUE 看过 2016-08-01 23:20:34

越多白痴的声音议论她，我对她仅存的回忆就越少。

### 2573 有用 饱肚师叔 看过 2016-08-09 23:58:43

笑了哭哭了笑。人老了真的很容易变得“讨人嫌”：我奶奶八十多岁有一次不小心滑倒骨折，之后她每天都在说，我为什么还不死，活着简直就在给大家添麻烦。那时候我回去看她，被她念得头疼。现在她九十好几，以为我还只有十五六岁，她好像记不太清年月，但有时候我又觉得，她其实什么都清楚。

> 更多短评 122087条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 一个叫欧维的男人决定去死的影评 · · · · · · ( 全部 1982 条 )

热门 / 最新 / 好友
kiki204629 2016-07-29 19:12:16

## 『一个叫欧维的男人和死神。 』

这篇影评可能有剧透

欧维。59岁。在他的工作岗位上已经奉献了43年，性格刻板，讲原则，脾气古怪执拗，带着坚不可摧的原则、每天恪守的常规以及随时发飙的脾性在居住的小社区晃来晃去，指责邻居家的狗狗随便便便，检查垃圾是否按规定分类，将孩子们空地上的随手乱丢的玩具摆放整齐，搬动随意停放的... (展开)
2896 262 185回应 收起
frozenmoon 2016-08-11 14:09:26

## 不进入一个人的历史，就不可能和他真正认识

（文/杨时旸） 客观地讲，这部《一个叫欧维的男人决定去死》其实缺乏成为热门电影的基础。它平缓、琐碎、缺乏真正意义上的戏剧高潮，但它之所以打动了那么多人，或许是因为它的主人公欧维，让我们想起了自己身边经常遭遇的那一类人：倔强、固执、对一切人和事都充满愤懑。... (展开)
1952 103 80回应 收起
媒介野 2016-07-31 03:43:36

## 我们选择死亡还是努力活着呢？

这篇影评可能有剧透

今天回家终于把这个瑞典温情小品看完了，故事非常简单，讲述了一个老头跌跌荡荡、有笑有泪的一生，整部影片的观感有些像《飞屋环游记》，而欧维就是真人版的卡尔。 「歐維的責任」 常言道「刀子嘴豆腐心」，形容的就是这个有些偏执狂的老人——欧维。影片一开始，你很难对这... (展开)
1513 69 69回应 收起
donger 2016-08-12 16:26:47

## 老天总让无聊且善良的人伤心，好像我们不会反击一样。

奇怪的欧洲片子，色调严肃，行人走起来认真又刻板，内心却善良的不得了。 来加州生活两年，越发确认了一种观点，气候决定我们成为如何生活的人。加州全年无休的阳光让我只想跑步，遛狗，成为躺在沙滩上拿脚踢都不动的快乐鬼，即使我根本不知道如何游泳，怎么应对海洋。最南端的... (展开)
680 29 35回应 收起
麦兜vinci 2017-02-25 01:19:22

## 萨博精神和瑞典文化

这篇影评可能有剧透

影片的故事和所要表达的情感显而易见，有好多影评都已经说的很透彻了，这里我想说一下影片背后所昭示的瑞典精神和瑞典人的偏执。 说到瑞典，在欧洲是一个比德国还具备处女座属性的北欧小国（其实德国人没有那么严谨的，不骗你们哈哈哈），瑞典人就像亚洲的日本人，是细节控是偏... (展开)
306 38回应 收起
淡淡 2016-07-31 21:39:20

## 像是我们每一个人，你们都要学会去爱。也要学会接受爱。同你们的全世界和解。

这篇影评可能有剧透

死亡对于前半部分的欧维来说，像是赴女孩约会那么美。然而他总也死不成——前半部分里的欧维没有一点喜剧的表演，我们却不由自主进入了荒诞喜剧的模式：总是在想还能怎么失败呢？好期待。。。为他每次接近成功而悲哀，为他的失败而失笑，松一口气，看他继续策划去死。 电影里... (展开)
263 17 23回应 收起
阅后即焚 2016-08-02 16:23:12

## 人生回首是好时 痴绝处的阳光渗透

这篇影评可能有剧透

北欧风格的电影大多是冷色调，给人的感受也多是寡淡叙事居多，然而这部电影的妙处也正是如此，冷色调的画面，并不讨喜的主人公，在银装素裹的雪国，通过无数次的回忆，一点点被融化，也带领着观众一点点心生暖意，直至在片尾处，在洒落的阳光中，火车摇晃的车厢内，与最亲... (展开)
123 11 11回应 收起
林子同 2017-01-21 16:26:46

## 一个叫欧维的男人和一个温暖的故事(包含原著与电影对比)

这篇影评可能有剧透

从来没有人问欧维遇见她之前他是怎么生活的。但要是有人问起，他一定会回答说自己没有生活。 ······ 要是有人问起，他会说，在她之前，他没有生活，之后也没有。 2015年12月，小说的中译本和改编电影《一个叫欧维的男人决定去死》分别上架和上映，两股温柔而坚韧的涌流同... (展开)
72 2 8回应 收起
Shiningboz 2016-08-10 17:18:56

## 你想不想去死一死

这篇影评可能有剧透

当初在微博上看到的推荐，推荐语说“希望你不要把这世界让给你讨厌的人”。 欧维，一个教科书式的傲娇老头，因为妻子的离世，在努力地，认真地去死。在影片的开头，弹幕里有人在猜想，电影的结局是不是当欧维不想去死了，但这个时候死亡却偏偏忽然来临了。当电影看到最后，我不... (展开)
76 1 3回应 收起
泡芙味的草莓 2017-06-11 18:36:16

## 一个叫欧维的男人决定去死

对这种絮絮叨叨温情脉脉的片子有好感，再加上有讲祖孙情的简直没有抵抗力虽然不是主线。男主演的天衣无缝，给人天生如此性格的感觉，女主虽然不漂亮却天生一种北欧的清丽脱俗，伊朗妈妈好评。 想必人人小的时候院儿里都有这样一个糟老头子，他恪守陈规常年累月执行着院子里的条... (展开)
27 3 0回应 收起

> 更多影评 1982篇

添加新讨论

## 讨论区 · · · · · ·

为什么社区工作者一定要接走鲁内？ | 来自周 | 4 回应 | 2022-11-22 22:01:53
Love is the eternal topic of humanity. | 来自顾廿 |  | 2022-11-22 14:58:38
怎么上热门了？ | 来自fan | 40 回应 | 2022-11-22 10:04:15
人怎么会太好呢 | 来自€ |  | 2022-11-18 12:31:18
嗯 | 来自€ |  | 2022-11-18 12:30:46

> 去这部影片的讨论区（全部209条）

## 关于《一个叫欧维的男人决定去死》的问题 · · · · · · ( 全部64个 )

- 欧维只有59岁？ 13人回答
- 有人知道片尾曲是什么吗？ 7人回答

> 全部64个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 生之绝望，惟有死亡才能逃脱羞辱 (阖昔)
- 北欧感觉 (有猫万事足)

## 谁在看这部电影 · · · · · ·

- 念。
  3分钟前 看过
- keo
  3分钟前 想看
- 柚子
  5分钟前 看过

669894人看过 / 422156人想看

订阅一个叫欧维的男人决定去死的评论:
feed: rss 2.0